@@ -223,11 +223,6 @@ vanessa_dynamic_array_t *vanessa_config_file_read_fd(int fd,
 		return(NULL);
 	}
 
-	if(!S_ISREG(stat_buf.st_mode)) {
-		VANESSA_LOGGER_DEBUG("configuration file is not a file");
-		return(NULL);
-	}
-
 	a = vanessa_dynamic_array_create(0, VANESSA_DESTROY_STR,
 		      VANESSA_DUPLICATE_STR, VANESSA_DISPLAY_STR,
 		      VANESSA_LENGTH_STR);
@@ -284,7 +279,7 @@ vanessa_dynamic_array_t *vanessa_config_file_read_fd(int fd,
 				END_ESCAPE;
 				break;
 			case '\\':
-				if (in_escape || in_quote) {
+				if (in_escape || in_quote & SINGLE_QUOTE) {
 					END_ESCAPE;
 				} else {
 					BEGIN_ESCAPE;
@@ -300,17 +295,18 @@ vanessa_dynamic_array_t *vanessa_config_file_read_fd(int fd,
 				break;
 			case '"':
 				BEGIN_VALUE;
-				if (!in_escape && !in_comment
-				    && !(in_quote & SINGLE_QUOTE)) {
+				if (!in_escape && !in_comment) {
 					if (in_quote & DOUBLE_QUOTE) {
 						in_quote ^=
 						    in_quote &
 						    DOUBLE_QUOTE;
 						last_escaped = token_pos;
-					} else {
+						skip_char = 1;
+					}
+					else if (!(in_quote & SINGLE_QUOTE)) {
 						in_quote |= DOUBLE_QUOTE;
+						skip_char = 1;
 					}
-					skip_char = 1;
 				}
 				END_ESCAPE;
 				break;
@@ -320,10 +316,12 @@ vanessa_dynamic_array_t *vanessa_config_file_read_fd(int fd,
 					if (in_quote & SINGLE_QUOTE) {
 						in_quote ^= SINGLE_QUOTE;
 						last_escaped = token_pos;
-					} else {
+						skip_char = 1;
+					}
+					else if (! (in_quote & DOUBLE_QUOTE)) {
 						in_quote |= SINGLE_QUOTE;
+						skip_char = 1;
 					}
-					skip_char = 1;
 				}
 				END_ESCAPE;
 				break;
